@@ -51,6 +51,11 @@ import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.text.contentassist.IContentAssistProcessor;
 import org.eclipse.jface.viewers.ICellEditorValidator;
 import org.eclipse.jface.window.Window;
+import org.eclipse.papyrus.infra.gmfdiag.common.editpart.PapyrusLabelEditPart;
+import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.ExternalLabelPrimaryDragRoleEditPolicy;
+import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.IMaskManagedLabelEditPolicy;
+import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.IndirectMaskLabelEditPolicy;
+import org.eclipse.papyrus.infra.gmfdiag.common.parsers.ParserUtil;
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.Activator;
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.configuration.IAdvancedEditorConfiguration;
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.configuration.ICustomDirectEditorConfiguration;
@@ -61,11 +66,6 @@ import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.ui.ILabelEditor
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.ui.IPopupEditorHelper;
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.utils.DirectEditorsUtil;
 import org.eclipse.papyrus.infra.gmfdiag.extensionpoints.editors.utils.IDirectEditorsIds;
-import org.eclipse.papyrus.infra.gmfdiag.common.editpart.PapyrusLabelEditPart;
-import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.ExternalLabelPrimaryDragRoleEditPolicy;
-import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.IMaskManagedLabelEditPolicy;
-import org.eclipse.papyrus.infra.gmfdiag.common.editpolicies.IndirectMaskLabelEditPolicy;
-import org.eclipse.papyrus.infra.gmfdiag.common.parsers.ParserUtil;
 import org.eclipse.papyrus.uml.diagram.activity.edit.policies.MaskManagedPinEditPolicy;
 import org.eclipse.papyrus.uml.diagram.activity.edit.policies.UMLTextSelectionEditPolicy;
 import org.eclipse.papyrus.uml.diagram.activity.figures.SimpleLabel;
@@ -117,14 +117,14 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * direct edition mode (default, undefined, registered editor, etc.)
-	 * 
+	 *
 	 * @generated
 	 */
 	protected int directEditionMode = IDirectEdition.UNDEFINED_DIRECT_EDITOR;
 
 	/**
 	 * configuration from a registered edit dialog
-	 * 
+	 *
 	 * @generated
 	 */
 	protected IDirectEditorConfiguration configuration;
@@ -146,6 +146,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void createDefaultEditPolicies() {
 		super.createDefaultEditPolicies();
 		installEditPolicy(EditPolicy.DIRECT_EDIT_ROLE, new LabelDirectEditPolicy());
@@ -157,6 +158,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public IBorderItemLocator getBorderItemLocator() {
 		IFigure parentFigure = getFigure().getParent();
 		if (parentFigure != null && parentFigure.getLayoutManager() != null) {
@@ -169,6 +171,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public void refreshBounds() {
 		int x = ((Integer) getStructuralFeatureValue(NotationPackage.eINSTANCE.getLocation_X())).intValue();
 		int y = ((Integer) getStructuralFeatureValue(NotationPackage.eINSTANCE.getLocation_Y())).intValue();
@@ -243,6 +246,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected List<?> getModelChildren() {
 		return Collections.EMPTY_LIST;
 	}
@@ -250,6 +254,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public IGraphicalEditPart getChildBySemanticHint(String semanticHint) {
 		return null;
 	}
@@ -295,6 +300,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public void setLabelText(String text) {
 		setLabelTextHelper(getFigure(), text);
 		Object pdEditPolicy = getEditPolicy(EditPolicy.PRIMARY_DRAG_ROLE);
@@ -310,6 +316,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public String getEditText() {
 		if (getParserElement() == null || getParser() == null) {
 			return ""; //$NON-NLS-1$
@@ -329,6 +336,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public ICellEditorValidator getEditTextValidator() {
 		return new ICellEditorValidator() {
 
@@ -339,7 +347,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 					final IParser parser = getParser();
 					try {
 						IParserEditStatus valid = (IParserEditStatus) getEditingDomain().runExclusive(
-								new RunnableWithResult.Impl<java.lang.Object>() {
+								new RunnableWithResult.Impl<>() {
 
 									@Override
 									public void run() {
@@ -361,6 +369,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public IContentAssistProcessor getCompletionProcessor() {
 		if (getParserElement() == null || getParser() == null) {
 			return null;
@@ -371,6 +380,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public ParserOptions getParserOptions() {
 		return ParserOptions.NONE;
 	}
@@ -378,6 +388,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	public IParser getParser() {
 		if (parser == null) {
 			parser = ParserUtil.getParser(UMLElementTypes.InputPin_TestIdentityActionSecondShape, getParserElement(), this, VISUAL_ID);
@@ -440,6 +451,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void performDirectEditRequest(Request request) {
 
 		final Request theRequest = request;
@@ -529,6 +541,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void refreshVisuals() {
 		super.refreshVisuals();
 		refreshLabel();
@@ -598,6 +611,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void refreshFont() {
 		FontStyle style = (FontStyle) getFontStyleOwnerView().getStyle(
 				NotationPackage.eINSTANCE.getFontStyle());
@@ -613,6 +627,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void setFontColor(Color color) {
 		getFigure().setForegroundColor(color);
 	}
@@ -620,6 +635,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void addSemanticListeners() {
 		if (getParser() instanceof ISemanticParser) {
 			EObject element = resolveSemanticElement();
@@ -635,6 +651,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void removeSemanticListeners() {
 		if (parserElements != null) {
 			for (int i = 0; i < parserElements.size(); i++) {
@@ -648,6 +665,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected AccessibleEditPart getAccessibleEditPart() {
 		if (accessibleEP == null) {
 			accessibleEP = new AccessibleGraphicalEditPart() {
@@ -670,7 +688,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Returns the kind of associated editor for direct edition.
-	 * 
+	 *
 	 * @return an <code>int</code> corresponding to the kind of direct editor, @see org.eclipse.papyrus.uml.diagram.common.editpolicies.IDirectEdition
 	 * @generated
 	 */
@@ -689,7 +707,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Checks if an extended editor is present.
-	 * 
+	 *
 	 * @return <code>true</code> if an extended editor is present.
 	 * @generated
 	 */
@@ -702,7 +720,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Checks if a default direct edition is available
-	 * 
+	 *
 	 * @return <code>true</code> if a default direct edition is available
 	 * @generated
 	 */
@@ -712,7 +730,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Initializes the extended editor configuration
-	 * 
+	 *
 	 * @generated
 	 */
 	protected void initExtendedEditorConfiguration() {
@@ -728,7 +746,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Updates the preference configuration
-	 * 
+	 *
 	 * @generated
 	 */
 	protected void updateExtendedEditorConfiguration() {
@@ -743,7 +761,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 
 	/**
 	 * Performs the direct edit usually used by GMF editors.
-	 * 
+	 *
 	 * @param theRequest
 	 *            the direct edit request that starts the direct edit system
 	 * @generated
@@ -777,6 +795,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected void handleNotificationEvent(Notification event) {
 		Object feature = event.getFeature();
 		if (NotationPackage.eINSTANCE.getFontStyle_FontColor().equals(feature)) {
@@ -812,6 +831,7 @@ public class InputPinInTestIdentityActionAsSecondLabelEditPart extends PapyrusLa
 	/**
 	 * @generated
 	 */
+	@Override
 	protected IFigure createFigure() {
 		IFigure label = createFigurePrim();
 		defaultText = getLabelTextHelper(label);
